package fr.openium.consentium_ui.ui.adapter

import fr.openium.consentium.api.model.PurposeChoice
import fr.openium.consentium.api.model.PurposeStatus
import fr.openium.consentium_ui.domain.model.ContentConfigData
import fr.openium.consentium_ui.ui.model.DetailConsentUI
import fr.openium.consentium_ui.ui.model.PurposeStatusUI
import fr.openium.consentium_ui.ui.model.PurposeUI

internal fun ContentConfigData.toDetailConsentUI(): DetailConsentUI = DetailConsentUI(
    conservationDurationText = mainTextTranslation.first().durationText,
    purposes = purposes.sortedBy { it.order }.map { it.toPurposeUI() },
    cookiePolicyUrl = mainTextTranslation.first().consentPageUrl,
)

internal fun DetailConsentUI.toPurposeChoices(): List<PurposeChoice> = purposes.map {
    it.toPurposeChoice()
}

internal fun DetailConsentUI.toDeniedPurposeChoices(): List<PurposeChoice> = purposes.map {
    it.toPurposeChoice().copy(choice = PurposeStatus.REJECTED)
}

internal fun DetailConsentUI.toAcceptedPurposeChoices(): List<PurposeChoice> = purposes.map {
    it.toPurposeChoice().copy(choice = PurposeStatus.ACCEPTED)
}

internal fun PurposeUI.toPurposeChoice(): PurposeChoice =
    PurposeChoice(
        purposeIdentifier = id,
        choice = choice.toPurposeStatus(),
        vendors = emptyList(), // Not in v1
    )

internal fun PurposeStatusUI.toPurposeStatus(): PurposeStatus =
    when (this) {
        PurposeStatusUI.ACCEPTED -> PurposeStatus.ACCEPTED
        PurposeStatusUI.REJECTED -> PurposeStatus.REJECTED
        PurposeStatusUI.PARTIAL -> PurposeStatus.PARTIAL
    }