package fr.openium.consentium_ui.ui.components.style

import androidx.compose.material3.LocalTextStyle
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.toArgb
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.sp
import androidx.core.graphics.ColorUtils


object ConsentiumDefaults {
    private const val OUTLINE_COLOR_BLEND_RATIO = 0.1f

    private object Typography {
        private val DEFAULT_LINE_HEIGHT = 24.sp
        private val LINE_HEIGHT_18 = 18.sp
        private val LINE_HEIGHT_22 = 22.sp
        private val DEFAULT_LETTER_SPACING = 0.5.sp

        val h1 = TextStyle(
            fontSize = 32.sp,
            fontWeight = FontWeight.SemiBold,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val h2 = TextStyle(
            fontSize = 24.sp,
            fontWeight = FontWeight.SemiBold,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val b1 = TextStyle(
            fontSize = 18.sp,
            fontWeight = FontWeight.SemiBold,
            lineHeight = DEFAULT_LINE_HEIGHT,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val p1 = TextStyle(
            fontSize = 18.sp,
            fontWeight = FontWeight.Normal,
            lineHeight = DEFAULT_LINE_HEIGHT,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val b2 = TextStyle(
            fontSize = 16.sp,
            fontWeight = FontWeight.SemiBold,
            lineHeight = LINE_HEIGHT_22,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val p2 = TextStyle(
            fontSize = 16.sp,
            fontWeight = FontWeight.Normal,
            lineHeight = LINE_HEIGHT_22,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val b3 = TextStyle(
            fontSize = 14.sp,
            fontWeight = FontWeight.SemiBold,
            lineHeight = LINE_HEIGHT_18,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val p3 = TextStyle(
            fontSize = 14.sp,
            fontWeight = FontWeight.Normal,
            lineHeight = LINE_HEIGHT_18,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val button = TextStyle(
            fontSize = 18.sp,
            fontWeight = FontWeight.SemiBold,
            letterSpacing = DEFAULT_LETTER_SPACING
        )

        val sm2 = TextStyle(
            fontSize = 16.sp,
            fontWeight = FontWeight.SemiBold,
            lineHeight = LINE_HEIGHT_22,
            letterSpacing = DEFAULT_LETTER_SPACING
        )
    }

    @Composable
    fun colors(
        primary: Color = MaterialTheme.colorScheme.primary,
        onPrimary: Color = MaterialTheme.colorScheme.onPrimary,
        secondary: Color = MaterialTheme.colorScheme.secondary,
        onSecondary: Color = MaterialTheme.colorScheme.surfaceVariant,
        tertiary: Color = MaterialTheme.colorScheme.onBackground,
        onSurfaceVariant: Color = MaterialTheme.colorScheme.onBackground,
        onSurface: Color = MaterialTheme.colorScheme.onBackground,
        outline: Color = Color(
            ColorUtils.blendARGB(
                onPrimary.toArgb(),
                primary.toArgb(),
                OUTLINE_COLOR_BLEND_RATIO,
            )
        ),
        error: Color = MaterialTheme.colorScheme.error,
        surfaceHighest: Color = MaterialTheme.colorScheme.surfaceContainerHighest,
        surfaceHigh: Color = MaterialTheme.colorScheme.surfaceContainerHigh,
        surfaceMiddle: Color = MaterialTheme.colorScheme.surfaceContainer,
        success: Color = Color(0xFF479B3F),
    ): ConsentiumColors = ConsentiumColors(
        primary = primary,
        onPrimary = onPrimary,
        secondary = secondary,
        onSecondary = onSecondary,
        tertiary = tertiary,
        onSurfaceVariant = onSurfaceVariant,
        onSurface = onSurface,
        outline = outline,
        error = error,
        surfaceHighest = surfaceHighest,
        surfaceHigh = surfaceHigh,
        surfaceMiddle = surfaceMiddle,
        success = success,
    )

    @Composable
    fun typography(
        h1: TextStyle = LocalTextStyle.current.merge(Typography.h1),
        h2: TextStyle = LocalTextStyle.current.merge(Typography.h2),
        b1: TextStyle = LocalTextStyle.current.merge(Typography.b1),
        p1: TextStyle = LocalTextStyle.current.merge(Typography.p1),
        b2: TextStyle = LocalTextStyle.current.merge(Typography.b2),
        p2: TextStyle = LocalTextStyle.current.merge(Typography.p2),
        b3: TextStyle = LocalTextStyle.current.merge(Typography.b3),
        p3: TextStyle = LocalTextStyle.current.merge(Typography.p3),
        button: TextStyle = LocalTextStyle.current.merge(Typography.button),
        sm2: TextStyle = LocalTextStyle.current.merge(Typography.sm2),
    ): ConsentiumTypography = ConsentiumTypography(
        h1 = h1,
        h2 = h2,
        b1 = b1,
        p1 = p1,
        b2 = b2,
        p2 = p2,
        b3 = b3,
        p3 = p3,
        button = button,
        sm2 = sm2,
    )
}

data class ConsentiumColors internal constructor(
    val primary: Color,
    val onPrimary: Color,
    val secondary: Color,
    val onSecondary: Color,
    val tertiary: Color,
    val onSurfaceVariant: Color,
    val onSurface: Color,
    val outline: Color,
    val error: Color,
    val surfaceHighest: Color,
    val surfaceHigh: Color,
    val surfaceMiddle: Color,
    val success: Color,
)

data class ConsentiumTypography internal constructor(
    val h1: TextStyle,
    val h2: TextStyle,
    val b1: TextStyle,
    val p1: TextStyle,
    val b2: TextStyle,
    val p2: TextStyle,
    val b3: TextStyle,
    val p3: TextStyle,
    val button: TextStyle,
    val sm2: TextStyle,
)
