package fr.openium.consentium

import android.content.Context
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.android.qualifiers.ApplicationContext
import dagger.hilt.components.SingletonComponent
import fr.openium.consentium.data.di.ConsentiumUrl
import fr.openium.consentium.data.di.NetworkModule
import okhttp3.HttpUrl
import okhttp3.HttpUrl.Companion.toHttpUrl
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import timber.log.Timber

@Module
@InstallIn(SingletonComponent::class)
class DevNetworkModule {

    @Provides
    fun provideOkHttpBuilder(
        @ApplicationContext context: Context,
    ): OkHttpClient.Builder =
        NetworkModule.standardOkHttpBuilder(context)
            .addNetworkInterceptor(HttpLoggingInterceptor { message ->
                Timber.tag("OkHttp")
                Timber.v(message)
            }.apply {
                level = HttpLoggingInterceptor.Level.BODY
            })

    @ConsentiumUrl
    @Provides
    fun okHttpUrlConsentium(@ApplicationContext context: Context): HttpUrl =
        context.getString(R.string.backend_url).toHttpUrl()
}