package fr.openium.consentium.data.remote.model

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable

internal sealed interface GetConsent {

    @Serializable
    data class GetConsentPayloadDTO(
        @SerialName("id") val id: String? = null,
        @SerialName("installationId") val installationId: String,
        @SerialName("state") val state: ConsentStateDTO? = null,
        @SerialName("acceptedDate") val acceptedData: Long? = null,
        @SerialName("purposes") val purposes: List<PurposeDTO>? = null,
    )

    @Serializable
    data class PurposeDTO(
        @SerialName("identifier") val identifier: String,
        @SerialName("choice") val choice: PurposeStatusDTO,
        @SerialName("vendors") val vendors: List<VendorDTO>? = null,
    )

    @Serializable
    data class VendorDTO(
        @SerialName("identifier") val identifier: String,
        @SerialName("isRequired") val isRequired: Boolean,
        @SerialName("isAccepted") val isAccepted: Boolean,
    )

    @Serializable
    enum class PurposeStatusDTO {
        @SerialName("accepted")
        ACCEPTED,

        @SerialName("refused")
        REJECTED,

        @SerialName("partial")
        PARTIAL,
    }

    @Serializable
    enum class ConsentStateDTO {
        @SerialName("unset")
        UNSET,

        @SerialName("valid")
        VALID,

        @SerialName("expired")
        EXPIRED,

        @SerialName("new_version")
        NEW_VERSION,
    }
}


